/*
 * Copyright 2009-2010  Stefan Gehn <stefan@srcbox.net>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of 
 * the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PHOTODRAGGABLE_H_
#define PHOTODRAGGABLE_H_

#include "Draggable.hpp"

class QPainter;

class PhotoDraggable : public Draggable
{
  Q_OBJECT
public:
  Q_PROPERTY(QPixmap pixmap READ pixmap WRITE setPixmap)

  PhotoDraggable(QGraphicsItem *parent = 0);
  virtual ~PhotoDraggable();

  void scaleAndRotate(qreal scaleFactor, qreal rotateAngle);

  virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);

  const QPixmap &pixmap() const;
  void setPixmap(const QPixmap &pm);

  static PhotoDraggable *createDraggable(const QString &photoPath, const QPointF &initialScenePos);

protected:
	virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent * event);
	virtual void resizeEvent(QGraphicsSceneResizeEvent *rev);
#if 0
	virtual void wheelEvent(QGraphicsSceneWheelEvent * event);
#endif
	QVariant itemChange(GraphicsItemChange change, const QVariant &value);

private:
  QGraphicsRectItem *mZoomRotateButton;
	QGraphicsRectItem *mDisableOverlay;
	QColor mBorderColor;
	QPixmap mPixmap;

	void updateBorderColor();
};

QDataStream & operator<< (QDataStream &stream, const PhotoDraggable &draggable);
QDataStream & operator>> (QDataStream &stream, PhotoDraggable &draggable);


#endif /* PHOTODRAGGABLE_H_ */
